var searchData=
[
  ['datachanged_0',['dataChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridDataListener.html#ab60475bc3d9da22e8a92c5732d5f112f',1,'com::sun::star::awt::grid::XGridDataListener']]],
  ['datadefinitioncausestransactioncommit_1',['dataDefinitionCausesTransactionCommit',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#ad7e6f25a1c6523b87642810310856da5',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['datadefinitionignoredintransactions_2',['dataDefinitionIgnoredInTransactions',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a7994d859ac1e857642c30144617a4fa8',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['deactivate_3',['deactivate',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame.html#a8308b4bb6079733f4b77ced9d46da7a9',1,'com::sun::star::frame::XFrame::deactivate()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowController.html#a8308b4bb6079733f4b77ced9d46da7a9',1,'com::sun::star::presentation::XSlideShowController::deactivate()']]],
  ['deactivated_4',['deactivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTabListener.html#a83b0691148b85681d7aa35b955a3bee6',1,'com::sun::star::awt::XTabListener::deactivated()'],['../interfacecom_1_1sun_1_1star_1_1embed_1_1XHatchWindowController.html#acfd4ec43396d90d144a6b27bfe409465',1,'com::sun::star::embed::XHatchWindowController::deactivated()']]],
  ['deactivatedinplace_5',['deactivatedInplace',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html#a635a2f25299ee2ee1749d80b3771ab25',1,'com::sun::star::embed::XInplaceClient']]],
  ['deactivatedui_6',['deactivatedUI',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html#abfdaeec64393e68223cb509f9ef210ff',1,'com::sun::star::embed::XInplaceClient']]],
  ['decrementindent_7',['decrementIndent',['../interfacecom_1_1sun_1_1star_1_1util_1_1XIndent.html#a0cae813e2a7cb188466a0ad7743261d6',1,'com::sun::star::util::XIndent']]],
  ['decrypt_8',['decrypt',['../interfacecom_1_1sun_1_1star_1_1packages_1_1XPackageEncryption.html#a4edf074ae3dcb792218c2207e5c74ad5',1,'com::sun::star::packages::XPackageEncryption::decrypt()'],['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLEncryption.html#afced3113c05468dc43d6e4e86e1fedf4',1,'com::sun::star::xml::crypto::XXMLEncryption::decrypt()']]],
  ['decrypted_9',['decrypted',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XDecryptionResultListener.html#a3746a0dc46dae72bef39c8b1a157c49a',1,'com::sun::star::xml::crypto::sax::XDecryptionResultListener']]],
  ['deletecomplexcategorylevel_10',['deleteComplexCategoryLevel',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XInternalDataProvider.html#a15f1760496d9adf10043d5eb42c04bbb',1,'com::sun::star::chart2::XInternalDataProvider']]],
  ['deleted_11',['deleted',['../interfacecom_1_1sun_1_1star_1_1form_1_1XDeleteListener.html#aa9001d62e2f4337d366235ac2345fbe7',1,'com::sun::star::form::XDeleteListener']]],
  ['deletedata_12',['deleteData',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XCharacterData.html#a9a6db4d0aaf4e4c6eaa87bad304b345b',1,'com::sun::star::xml::dom::XCharacterData']]],
  ['deletedatapointforallsequences_13',['deleteDataPointForAllSequences',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XInternalDataProvider.html#a153b78133c92d22139ddf2875231005c',1,'com::sun::star::chart2::XInternalDataProvider']]],
  ['deletekey_14',['deleteKey',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#a4449e965b4d4691b04ed2b47d68a7bdd',1,'com::sun::star::registry::XRegistryKey']]],
  ['deletelink_15',['deleteLink',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#af9c415f2f53db0c3438f99579b5016db',1,'com::sun::star::registry::XRegistryKey']]],
  ['deletelist_16',['deleteList',['../interfacecom_1_1sun_1_1star_1_1system_1_1windows_1_1XJumpList.html#a4bb9f7b9d13416cb606218a8b8e07022',1,'com::sun::star::system::windows::XJumpList']]],
  ['deletemark_17',['deleteMark',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a36772bc144f3ee17ca57a664c84cdb22',1,'com::sun::star::io::XMarkableStream']]],
  ['deleterow_18',['deleteRow',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSetUpdate.html#a6c27dcd1cddd7b11d23e00417976255a',1,'com::sun::star::sdbc::XResultSetUpdate']]],
  ['deleterows_19',['deleteRows',['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XDeleteRows.html#ad3cf2d939ffa760750a960ad58ca57b4',1,'com::sun::star::sdbcx::XDeleteRows']]],
  ['deletesaredetected_20',['deletesAreDetected',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a8acc6c6c32d49b08f91743da43d2fc65',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['deletesequence_21',['deleteSequence',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XInternalDataProvider.html#aa35393060b4e291aaf7099dbc9934db2',1,'com::sun::star::chart2::XInternalDataProvider']]],
  ['deletetext_22',['deleteText',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEditableText.html#ad9f28742fbd403c7eb0fbdfef69bb150',1,'com::sun::star::accessibility::XAccessibleEditableText']]],
  ['deregistercontentprovider_23',['deregisterContentProvider',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentProviderManager.html#a7a126da4c2507e3417ff5edfd01f0a0a',1,'com::sun::star::ucb::XContentProviderManager']]],
  ['deregistercontroller_24',['deregisterController',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XUIControllerRegistration.html#ac0c722f4344261e5b9925c86a8aaee76',1,'com::sun::star::frame::XUIControllerRegistration']]],
  ['deregisterfactory_25',['deregisterFactory',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XUIElementFactoryRegistration.html#ae36ba28492673307006cac26191adb06',1,'com::sun::star::ui::XUIElementFactoryRegistration']]],
  ['deregisterinstance_26',['deregisterInstance',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XParameterizedContentProvider.html#a0bf349dc612aaec5e4668a5e1155af2e',1,'com::sun::star::ucb::XParameterizedContentProvider']]],
  ['describecategories_27',['describeCategories',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XObjectInspectorModel.html#a4afdc580f5df198c28b7e533ce8a3f81',1,'com::sun::star::inspection::XObjectInspectorModel']]],
  ['describelayer_28',['describeLayer',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerContentDescriber.html#a249481cc196d2acf3e2682a2b4d68c61',1,'com::sun::star::configuration::backend::XLayerContentDescriber']]],
  ['describepropertyline_29',['describePropertyLine',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyHandler.html#adda640274afc808fe17fe7e72ba8e5e2',1,'com::sun::star::inspection::XPropertyHandler']]],
  ['descriptorchanged_30',['descriptorChanged',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionChangeListener.html#a67c374f5433f82aefeb4a1ffa89cf480',1,'com::sun::star::sheet::XRangeSelectionChangeListener']]],
  ['deselectaccessiblechild_31',['deselectAccessibleChild',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleSelection.html#a2bdf6c4c2645afbcf540fa1d0cf3643c',1,'com::sun::star::accessibility::XAccessibleSelection']]],
  ['deselectallrows_32',['deselectAllRows',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html#a58319da156691ecc5ebceac5cbb3f839',1,'com::sun::star::awt::grid::XGridRowSelection']]],
  ['deselectrow_33',['deselectRow',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html#a79e70c5340be3a516c47ff51a59ce02c',1,'com::sun::star::awt::grid::XGridRowSelection']]],
  ['destroy_34',['destroy',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a3a80b6032f86a56bec74609034b3246f',1,'com::sun::star::registry::XSimpleRegistry']]],
  ['destroybuffers_35',['destroyBuffers',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XBufferController.html#aac3d764e57ec1064b7b82ec8322404e3',1,'com::sun::star::rendering::XBufferController']]],
  ['destroyelement_36',['destroyElement',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#a0b443e2c14b98bdd4392593094845fd7',1,'com::sun::star::frame::XLayoutManager']]],
  ['destroygraph_37',['destroyGraph',['../interfacecom_1_1sun_1_1star_1_1rdf_1_1XRepository.html#a5cac8eee77b972e38e42896253a68e8f',1,'com::sun::star::rdf::XRepository']]],
  ['detach_38',['detach',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacherManager.html#a3fe259f5a6328e0924178db9d78289ca',1,'com::sun::star::script::XEventAttacherManager']]],
  ['detect_39',['detect',['../interfacecom_1_1sun_1_1star_1_1document_1_1XExtendedFilterDetection.html#a83f8a8ae5fc3ea370002c78e7164569c',1,'com::sun::star::document::XExtendedFilterDetection::detect()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XExtendedFilterDetection.html#ac575499aa1fb6c8eb25f4b7ee646e85e',1,'com::sun::star::frame::XExtendedFilterDetection::detect()']]],
  ['detectarguments_40',['detectArguments',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataProvider.html#a5f4349946818f3e5856ba62e9636a631',1,'com::sun::star::chart2::data::XDataProvider']]],
  ['detectnumberformat_41',['detectNumberFormat',['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatter.html#a108d65c193eeb89feb9ba9c7152d62b0',1,'com::sun::star::util::XNumberFormatter']]],
  ['dialogclosed_42',['dialogClosed',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XDialogClosedListener.html#af09e15128ac384291d08ca9d3e59e0cf',1,'com::sun::star::ui::dialogs::XDialogClosedListener']]],
  ['dialogsizechanged_43',['dialogSizeChanged',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePickerListener.html#abe271f68736448f35ac49b8a63461720',1,'com::sun::star::ui::dialogs::XFilePickerListener']]],
  ['directinvoke_44',['directInvoke',['../interfacecom_1_1sun_1_1star_1_1script_1_1XDirectInvocation.html#a97aba223f7dfb6b8cd6ce30180ad0338',1,'com::sun::star::script::XDirectInvocation']]],
  ['directorychanged_45',['directoryChanged',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePickerListener.html#ac35eaa1b73aff700b2d6048a572efe18',1,'com::sun::star::ui::dialogs::XFilePickerListener']]],
  ['disableautomaticdeviceselection_46',['disableAutomaticDeviceSelection',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1opencl_1_1XOpenCLSelection.html#a9c664372512c38f7c9d9d65ceced2240',1,'com::sun::star::sheet::opencl::XOpenCLSelection']]],
  ['disableextension_47',['disableExtension',['../interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a9661c24f9e0c8d40c93b00fbb1bff0e6',1,'com::sun::star::deployment::XExtensionManager']]],
  ['disablelanguages_48',['disableLanguages',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a7b9ca699b6272297814c738f6fe57ea4',1,'com::sun::star::linguistic2::XLanguageGuessing']]],
  ['disableopcodesubsettest_49',['disableOpcodeSubsetTest',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1opencl_1_1XOpenCLSelection.html#a5d642d8661317a2e091ce11e13cb1dbc',1,'com::sun::star::sheet::opencl::XOpenCLSelection']]],
  ['disablesetmodified_50',['disableSetModified',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModifiable2.html#a1ea0e61ea83fb3730d9affc83c4549dd',1,'com::sun::star::util::XModifiable2']]],
  ['disconnect_51',['disconnect',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailService.html#a960705de531a20389fb29928d43258c3',1,'com::sun::star::mail::XMailService']]],
  ['disconnectbegin_52',['disconnectBegin',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectorShape.html#ad84d3d34e890958dfbb7a1ced3d8f7d7',1,'com::sun::star::drawing::XConnectorShape']]],
  ['disconnectcontroller_53',['disconnectController',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XModel.html#a1efc32d47b6408c0a510abf0a01622df',1,'com::sun::star::frame::XModel']]],
  ['disconnected_54',['disconnected',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html#ae87c39da796169476f3eaab5a1528393',1,'com::sun::star::mail::XConnectionListener']]],
  ['disconnectend_55',['disconnectEnd',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectorShape.html#abd0fccf5cc6d10ec30ea06efe312d88b',1,'com::sun::star::drawing::XConnectorShape']]],
  ['disconnectfromall_56',['disconnectFromAll',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderDistributor.html#a549491c406bde05ac22cd2c3f9acbe7f',1,'com::sun::star::ucb::XRemoteContentProviderDistributor']]],
  ['disconnectfromremoteacceptor_57',['disconnectFromRemoteAcceptor',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderDistributor.html#a6143aa63b06e4ceabfa361955fb71eb4',1,'com::sun::star::ucb::XRemoteContentProviderDistributor']]],
  ['disconnectpersistence_58',['disconnectPersistence',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XPersistanceHolder.html#ab2d9992cb1020bc344489c35334110a1',1,'com::sun::star::embed::XPersistanceHolder']]],
  ['disjunctivetermadded_59',['disjunctiveTermAdded',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterControllerListener.html#a1c9d4332c5ed65d653aa07918f8af9a7',1,'com::sun::star::form::runtime::XFilterControllerListener']]],
  ['disjunctivetermremoved_60',['disjunctiveTermRemoved',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterControllerListener.html#a775861632c4d938a56bae5ce6daeefca',1,'com::sun::star::form::runtime::XFilterControllerListener']]],
  ['dispatch_61',['dispatch',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatch.html#a42beb1ea2ddae35c076b6e65867025ea',1,'com::sun::star::frame::XDispatch']]],
  ['dispatchandrecord_62',['dispatchAndRecord',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchRecorderSupplier.html#ab7a4aa2544fd4d24b09b811835c6a960',1,'com::sun::star::frame::XDispatchRecorderSupplier::dispatchAndRecord()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XRecordableDispatch.html#a41bee0cab597faf0252c15f0c232eda3',1,'com::sun::star::frame::XRecordableDispatch::dispatchAndRecord()']]],
  ['dispatchevent_63',['dispatchEvent',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1XEventTarget.html#a6046468dbd89208e58378a748587c257',1,'com::sun::star::xml::dom::events::XEventTarget']]],
  ['dispatchfinished_64',['dispatchFinished',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchResultListener.html#a6afe09bc132baafd4742a656e083f1f2',1,'com::sun::star::frame::XDispatchResultListener']]],
  ['dispatchwithnotification_65',['dispatchWithNotification',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XNotifyingDispatch.html#ad9450aa0c2b962235991f144c0194597',1,'com::sun::star::frame::XNotifyingDispatch']]],
  ['dispatchwithreturnvalue_66',['dispatchWithReturnValue',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSynchronousDispatch.html#ac263adb47abe152c597bf1f7eba99cd1',1,'com::sun::star::frame::XSynchronousDispatch']]],
  ['displaypropertypage_67',['displayPropertyPage',['../interfacecom_1_1sun_1_1star_1_1smarttags_1_1XSmartTagRecognizer.html#a6037a9249d025a918ddfc1288c35e297',1,'com::sun::star::smarttags::XSmartTagRecognizer']]],
  ['displayslide_68',['displaySlide',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#a3fedf5bfed415453062ae51a6d5056c7',1,'com::sun::star::presentation::XSlideShow']]],
  ['dispose_69',['dispose',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XComponent.html#ab953e90edb69534eb052f9064f6b40e9',1,'com::sun::star::lang::XComponent::dispose()'],['../interfacecom_1_1sun_1_1star_1_1uno_1_1XReference.html#ab953e90edb69534eb052f9064f6b40e9',1,'com::sun::star::uno::XReference::dispose()']]],
  ['disposing_70',['disposing',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XEventListener.html#aae6e796f0b3b6a2dba2c1a6bda1a10a1',1,'com::sun::star::lang::XEventListener']]],
  ['doaccessibleaction_71',['doAccessibleAction',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleAction.html#aa0f4dced146836460d9e6ba2a19349a7',1,'com::sun::star::accessibility::XAccessibleAction']]],
  ['dockallwindows_72',['dockAllWindows',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#ae4a8842b2b88ed4aaeba0f95e15cc60f',1,'com::sun::star::frame::XLayoutManager']]],
  ['docking_73',['docking',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XDockableWindowListener.html#af094338273532b66bf689947a4ed18e2',1,'com::sun::star::awt::XDockableWindowListener']]],
  ['dockwindow_74',['dockWindow',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#a5880278040cc84dad5296f0981dfefce',1,'com::sun::star::frame::XLayoutManager']]],
  ['doconnect_75',['doConnect',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectableShape.html#a9e67033b7041632dcf38a822b87a82d4',1,'com::sun::star::drawing::XConnectableShape']]],
  ['docontinue_76',['doContinue',['../interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a365dd2e330b51218ece765cf76af4595',1,'com::sun::star::script::XDebugging']]],
  ['documentcloserctor1_77',['DocumentCloserCtor1',['../servicecom_1_1sun_1_1star_1_1embed_1_1DocumentCloser.html#ae901f97b9ae8cd407ec0bd1841c587f8',1,'com::sun::star::embed::DocumentCloser']]],
  ['documenteventoccured_78',['documentEventOccured',['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentEventListener.html#a5c95292679df32e6aa303ec0d7671784',1,'com::sun::star::document::XDocumentEventListener']]],
  ['doesmaxrowsizeincludeblobs_79',['doesMaxRowSizeIncludeBlobs',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#ae1455302415da6084e5f22de0a8115f7',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['doimport_80',['doImport',['../interfacecom_1_1sun_1_1star_1_1util_1_1XImportable.html#a621658ff2b790ece6f521d668a41e101',1,'com::sun::star::util::XImportable']]],
  ['dolayout_81',['doLayout',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#abf88fa0b9edf8ede8c6b1bd9e3510d4f',1,'com::sun::star::frame::XLayoutManager']]],
  ['done_82',['done',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XRangeSelectionListener.html#ac2f17a54d8be88033da9bf8b4698fa70',1,'com::sun::star::sheet::XRangeSelectionListener']]],
  ['donewithremotecontentproviders_83',['doneWithRemoteContentProviders',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderDoneListener.html#aa5d4d224e686f4d10ac7ec925e49198c',1,'com::sun::star::ucb::XRemoteContentProviderDoneListener']]],
  ['doprivileged_84',['doPrivileged',['../interfacecom_1_1sun_1_1star_1_1security_1_1XAccessController.html#ae3cc71d997fc2fb089d7c29e479b2224',1,'com::sun::star::security::XAccessController']]],
  ['doproofreading_85',['doProofreading',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XProofreader.html#a5c687e09b0c816e228c20803c2d1b0c1',1,'com::sun::star::linguistic2::XProofreader']]],
  ['doquit_86',['doQuit',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerListener2.html#a7a2fbaa46dfb3e9233d4a068e8a9c268',1,'com::sun::star::frame::XSessionManagerListener2']]],
  ['dorestore_87',['doRestore',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerListener.html#ac88e16758f53552c935feefd7dff4c78',1,'com::sun::star::frame::XSessionManagerListener']]],
  ['dorestricted_88',['doRestricted',['../interfacecom_1_1sun_1_1star_1_1security_1_1XAccessController.html#ab3d90090c50252d818803cf86cda9635',1,'com::sun::star::security::XAccessController']]],
  ['dosave_89',['doSave',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerListener.html#a26498ad11ec38b2614e2cf5e56ff5a93',1,'com::sun::star::frame::XSessionManagerListener']]],
  ['doscaling_90',['doScaling',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XScaling.html#a674daff794ca084bf1229963e23bc865',1,'com::sun::star::chart2::XScaling']]],
  ['doubleclick_91',['doubleClick',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XStatusbarController.html#a9ab62e3d98e96846e553805206a4510f',1,'com::sun::star::frame::XStatusbarController::doubleClick()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XToolbarController.html#a029af899a4779fe3577bcdbb68c2946c',1,'com::sun::star::frame::XToolbarController::doubleClick()']]],
  ['doverb_92',['doVerb',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XEmbeddedObject.html#af02a6df42b7bcc536d8cd1c52b4e86dc',1,'com::sun::star::embed::XEmbeddedObject']]],
  ['down_93',['down',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinField.html#a6663cf1e20c2f8162d29d31c8f6324e6',1,'com::sun::star::awt::XSpinField::down()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinListener.html#aadc9384d0b0582584dc587c3e4068a51',1,'com::sun::star::awt::XSpinListener::down()']]],
  ['dragdropend_94',['dragDropEnd',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#a53d5bd969e7911686436ad6d0615caf5',1,'com::sun::star::datatransfer::dnd::XDragSourceListener']]],
  ['dragenter_95',['dragEnter',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#aeb1254a76ac041854da438cbb2d76e03',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dragEnter()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#a1f0800723ea156e271cdc17f28e84b56',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dragEnter()']]],
  ['dragexit_96',['dragExit',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#a985b1df1ec59b6f07b85a3e7df95e7e5',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dragExit()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#a5bb38bbdf63cfdc866e1f08db1065189',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dragExit()']]],
  ['draggesturerecognized_97',['dragGestureRecognized',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragGestureListener.html#a7a469b62d7cc8148a1bd032036c2eced',1,'com::sun::star::datatransfer::dnd::XDragGestureListener']]],
  ['dragover_98',['dragOver',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#a727b75f0dab7ecc974476dcc66026f06',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dragOver()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#afa669a5669dbb67d5a548d9103fa0a2a',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dragOver()']]],
  ['draw_99',['draw',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a4ea3de0291b97137621a9f9a815d0c2d',1,'com::sun::star::awt::XGraphics::draw()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XView.html#adce2d92a1139e5b7cb82981264070814',1,'com::sun::star::awt::XView::draw()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XMtfRenderer.html#ac23bdb89ec917c28ac19f374abc21099',1,'com::sun::star::rendering::XMtfRenderer::draw()']]],
  ['drawarc_100',['drawArc',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a8554b44445ddb7337ea518872014e3a9',1,'com::sun::star::awt::XGraphics']]],
  ['drawbezier_101',['drawBezier',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#af8c89b14291cedce5db368f6165ec92c',1,'com::sun::star::rendering::XCanvas']]],
  ['drawbitmap_102',['drawBitmap',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a015d88244db674156d2dd2d239a3e671',1,'com::sun::star::rendering::XCanvas::drawBitmap()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#abe76e8727aee779e231ce30d29b60fb5',1,'com::sun::star::rendering::XSimpleCanvas::drawBitmap()']]],
  ['drawbitmapmodulated_103',['drawBitmapModulated',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a29605a8019c1a8555a38a751bc87cf78',1,'com::sun::star::rendering::XCanvas']]],
  ['drawchord_104',['drawChord',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#acb96effd798f5245a968fec05198c0c9',1,'com::sun::star::awt::XGraphics']]],
  ['drawellipse_105',['drawEllipse',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#af13395b31b5fe42e75fa2dd3be126d0d',1,'com::sun::star::awt::XGraphics']]],
  ['drawgradient_106',['drawGradient',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a6ad1fd8d0e4a09392e9e5ab1208423ac',1,'com::sun::star::awt::XGraphics']]],
  ['drawimage_107',['drawImage',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics2.html#a9b5963f4e44df485d78798003f1f604f',1,'com::sun::star::awt::XGraphics2']]],
  ['drawline_108',['drawLine',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a7199165a0bb06a40b59e8eeabff9ee25',1,'com::sun::star::awt::XGraphics::drawLine()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#af188a3bfefc55acd11b2a24e514fcb75',1,'com::sun::star::rendering::XCanvas::drawLine()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#a20b0570e648aad820eb167f799d03463',1,'com::sun::star::rendering::XSimpleCanvas::drawLine()']]],
  ['drawpie_109',['drawPie',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a61b8321831e861a1b5f563ba63d54335',1,'com::sun::star::awt::XGraphics']]],
  ['drawpixel_110',['drawPixel',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#af6dd0f8c608011b08cbaab7f49d24a2c',1,'com::sun::star::awt::XGraphics::drawPixel()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#a1af51829ba72a73c0a6d7dd6ab520bc7',1,'com::sun::star::rendering::XSimpleCanvas::drawPixel()']]],
  ['drawpoint_111',['drawPoint',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#ae91aabce5b2b8fece303138ffc4cd669',1,'com::sun::star::rendering::XCanvas']]],
  ['drawpolygon_112',['drawPolygon',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a5741b1e6f21fb5584dc8496197efccaa',1,'com::sun::star::awt::XGraphics']]],
  ['drawpolyline_113',['drawPolyLine',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a56f50a285672d7ed69b9cf34562ea94c',1,'com::sun::star::awt::XGraphics']]],
  ['drawpolypolygon_114',['drawPolyPolygon',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a1cea898bba12b80148cd3d8483fd2463',1,'com::sun::star::awt::XGraphics::drawPolyPolygon()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a5b37e1456b7db1f9c3c8d2f31e1ca0e1',1,'com::sun::star::rendering::XCanvas::drawPolyPolygon()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#a97e1c3812e715ed269a5d4e46bd04e72',1,'com::sun::star::rendering::XSimpleCanvas::drawPolyPolygon()']]],
  ['drawrect_115',['drawRect',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#ab18470b0d531232ef86df7e348bd51b9',1,'com::sun::star::awt::XGraphics::drawRect()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#a7230c2d9337a27a4fd8e313768b44033',1,'com::sun::star::rendering::XSimpleCanvas::drawRect()']]],
  ['drawroundedrect_116',['drawRoundedRect',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#ac25f55e7df3ffff7ff8ca2d1b886dc2f',1,'com::sun::star::awt::XGraphics']]],
  ['drawtext_117',['drawText',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a3b5461dd56ead4d80e8aacf91bd6224f',1,'com::sun::star::awt::XGraphics::drawText()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a067eead9e2ebdfd2d8125b23e83e8fba',1,'com::sun::star::rendering::XCanvas::drawText()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#ab9025cbb3845a4090b87b021b288ea08',1,'com::sun::star::rendering::XSimpleCanvas::drawText()']]],
  ['drawtextarray_118',['drawTextArray',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a5823270f9a31c5d7258670ae721f8978',1,'com::sun::star::awt::XGraphics']]],
  ['drawtextlayout_119',['drawTextLayout',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a716e2ac0ee24cd191ec1a8ce7d02a97c',1,'com::sun::star::rendering::XCanvas']]],
  ['drop_120',['drop',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#acd39324279313e59fabf50fdb811f0c7',1,'com::sun::star::datatransfer::dnd::XDropTargetListener']]],
  ['dropactionchanged_121',['dropActionChanged',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#ab24f3c8fd4910917334d78d82a637251',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dropActionChanged()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#aaf47bd1a322942de8307c3045a0cd5ee',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dropActionChanged()']]],
  ['dropbyindex_122',['dropByIndex',['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XDrop.html#af25d33157d20ad6f948d6c6ffb9077ca',1,'com::sun::star::sdbcx::XDrop']]],
  ['dropbyname_123',['dropByName',['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XDrop.html#a32d6e90168e7b010d06315594484bb83',1,'com::sun::star::sdbcx::XDrop']]],
  ['dropcatalog_124',['dropCatalog',['../interfacecom_1_1sun_1_1star_1_1sdbcx_1_1XDropCatalog.html#ae19942e49c8c1afac747ac283ecc3277',1,'com::sun::star::sdbcx::XDropCatalog']]],
  ['dropcolumn_125',['dropColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableAlteration.html#a97235c0691410ceb0e9b0cb8a5a1763e',1,'com::sun::star::sdb::tools::XTableAlteration']]],
  ['dropcomplete_126',['dropComplete',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetDropContext.html#a2c53f2bead85a27e170a735ff48aa802',1,'com::sun::star::datatransfer::dnd::XDropTargetDropContext']]],
  ['dropindex_127',['dropIndex',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XIndexAlteration.html#a90d980f59febcecef0a9836ae42aeb2e',1,'com::sun::star::sdb::tools::XIndexAlteration']]],
  ['dropkey_128',['dropKey',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XKeyAlteration.html#a0fa2e8cc2ffddf319037f3bb707b98dd',1,'com::sun::star::sdb::tools::XKeyAlteration']]],
  ['dropnode_129',['dropNode',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerHandler.html#a314d7171578defbb61cbd17d3f0a9e4f',1,'com::sun::star::configuration::backend::XLayerHandler']]],
  ['dump_130',['dump',['../interfacecom_1_1sun_1_1star_1_1qa_1_1XDumper.html#a376da8778c04ef7d2ec3b4e38cf11adb',1,'com::sun::star::qa::XDumper']]],
  ['dumpany_131',['dumpAny',['../interfacecom_1_1sun_1_1star_1_1reflection_1_1XDump.html#adfb4f7a1e02054a5e66568de479442bf',1,'com::sun::star::reflection::XDump']]],
  ['dumpconstant_132',['dumpConstant',['../interfacecom_1_1sun_1_1star_1_1reflection_1_1XDump.html#a44bfaeff663ecbf3f1b4c9e7cf3d4e6b',1,'com::sun::star::reflection::XDump']]],
  ['dumpvalue_133',['dumpValue',['../interfacecom_1_1sun_1_1star_1_1reflection_1_1XDump.html#a59d52f5f2deee6d9ea90fc9149754855',1,'com::sun::star::reflection::XDump']]],
  ['dumpvariable_134',['dumpVariable',['../interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#ad1d17160256f27afa3cf1d4266303d1e',1,'com::sun::star::script::XDebugging']]],
  ['duplicate_135',['duplicate',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPageDuplicator.html#a029c790ab6371eed1bf392b328673c91',1,'com::sun::star::drawing::XDrawPageDuplicator']]]
];
